import 'package:json_annotation/json_annotation.dart';

/// @~english
/// @brief Result value.
/// @details The result value returned by PANO methods, indicating the execution status.
/// @~chinese
/// @brief 返回。
/// @details PANO方法返回值，指示执行的情况。
enum ResultCode {
  /// @~english Execution succeed. @~chinese 执行成功。
  @JsonValue(0)
  OK,

  /// @~english Execution failed. @~chinese 执行失败。
  @JsonValue(-1)
  Failed,

  /// @~english Fatal error. @~chinese 致命错误。
  @JsonValue(-2)
  Fatal,

  /// @~english Invalid argument. @~chinese 非法参数。
  @JsonValue(-3)
  InvalidArgs,

  /// @~english Invalid state. @~chinese 非法状态。
  @JsonValue(-4)
  InvalidState,

  /// @~english Invalid index. @~chinese 无效索引。
  @JsonValue(-5)
  InvalidIndex,

  /// @~english The object already exists. @~chinese 对象已存在。
  @JsonValue(-6)
  AlreadyExist,

  /// @~english The object does not exist. @~chinese 对象不存在。
  @JsonValue(-7)
  NotExist,

  /// @~english The object is not found. @~chinese 对象没发现。
  @JsonValue(-8)
  NotFound,

  /// @~english The method is not supported. @~chinese 方法不支持。
  @JsonValue(-9)
  NotSupported,

  /// @~english The method is not implemented. @~chinese 方法未实现。
  @JsonValue(-10)
  NotImplemented,

  /// @~english The object is not initialized. @~chinese 对象未初始化。
  @JsonValue(-11)
  NotInitialized,

  /// @~english The resource limit is reached. @~chinese 已达上限。
  @JsonValue(-12)
  LimitReached,

  /// @~english No privilege to do. @~chinese 没有权限执行该操作。
  @JsonValue(-13)
  NoPrivilege,

  /// @~english Operation in progress. @~chinese 操作正在进行中。
  @JsonValue(-14)
  InProgress,

  /// @~english The operation thread is wrong. @~chinese 操作的线程错误。
  @JsonValue(-15)
  WrongThread,

  /// @~english Authentication failed. @~chinese 认证失败。
  @JsonValue(-101)
  AuthFailed,

  /// @~english The user is rejected. @~chinese 用户被拒绝。
  @JsonValue(-102)
  UserRejected,

  /// @~english The user is expelled. @~chinese 用户被驱逐。
  @JsonValue(-103)
  UserExpelled,

  /// @~english The user ID is duplicate. @~chinese 用户 ID 重复。
  @JsonValue(-104)
  UserDuplicate,

  /// @~english The channel is closed. @~chinese 频道被关闭。
  @JsonValue(-151)
  ChannelClosed,

  /// @~english The channel capacity is full. @~chinese 频道容量已满。
  @JsonValue(-152)
  ChannelFull,

  /// @~english The channel is locked. @~chinese 频道被锁定。
  @JsonValue(-153)
  ChannelLocked,

  /// @~english The channel mode is mismatch. @~chinese 频道模式不匹配。
  @JsonValue(-154)
  ChannelModeMismatch,

  /// @~english A network error occurred. @~chinese 出现网络错误。
  @JsonValue(-301)
  NetworkError,
}

/// @brief @~english Failover state. @~chinese 故障转移状态。
enum FailoverState {
  /// @~english Failover is reconnecting. @~chinese 发生故障转移，正在重新连接。
  @JsonValue(0)
  Reconnecting,

  /// @~english Failover succeeded. @~chinese 故障转移成功。
  @JsonValue(1)
  Success,

  /// @~english Failover failed. @~chinese 故障转移失败。
  @JsonValue(2)
  Failed,
}

/// @brief @~english Channel mode. @~chinese 频道模式。
enum ChannelMode {
  /// @~english 1-on-1 channel mode. @~chinese 1对1频道模式。
  @JsonValue(0)
  OneOnOne,

  /// @~english Meeting channel mode. @~chinese 会议频道模式。
  @JsonValue(1)
  Meeting,
}

/// @brief @~english Channel service flag. @~chinese 频道服务标志。
enum ChannelService {
  /// @~english Channel enable media service. @~chinese 频道启用媒体服务。
  @JsonValue(1 << 0)
  Media,

  /// @~english Channel enable whiteboard service. @~chinese 频道启用白板服务。
  @JsonValue(1 << 1)
  Whiteboard,
}

/// @brief @~english User leave reason. @~chinese 用户离开原因。
enum UserLeaveReason {
  /// @~english The user leaves normally. @~chinese 用户正常离开。
  @JsonValue(0)
  Normal,

  /// @~english The user is expelled. @~chinese 用户被驱逐。
  @JsonValue(1)
  Expelled,

  /// @~english The user is disconnected. @~chinese 用户掉线。
  @JsonValue(2)
  Disconnected,

  /// @~english Channel is end. @~chinese 频道结束
  @JsonValue(3)
  ChannelEnd,

  /// @~english The user ID is duplicate. @~chinese 用户 ID 重复
  @JsonValue(4)
  DuplicateUserID,
}

/// @brief @~english The result to subscribe user media. @~chinese 用户媒体订阅结果。
enum SubscribeResult {
  /// @~english subscribe success. @~chinese 订阅成功。
  @JsonValue(0)
  Success,

  /// @~english subscribe failed. @~chinese 订阅失败。
  @JsonValue(1)
  Failed,

  /// @~english the user is not found. @~chinese 被订阅的用户不存在。
  @JsonValue(2)
  UserNotFound,

  /// @~english the subscribe limit is reached. @~chinese 达到订阅上限。
  @JsonValue(3)
  LimitReached,
}

/// @brief @~english Video profile type. @~chinese 视频设定类型。
enum VideoProfileType {
  /// @~english The lowest video profile. Resolution：160 x 90 or 160 x 120, frame rate: 15 fps.
  /// @~chinese 最低档视频设定。分辨率：160 x 90 或 160 x 120，帧率：15 帧/秒。
  @JsonValue(0)
  Lowest,

  /// @~english The lower video profile. 320 x 180 or 320 x 240, frame rate: 15 fps.
  /// @~chinese 低档视频设定。分辨率：320 x 180 或 320 x 240，帧率：15 帧/秒。
  @JsonValue(1)
  Low,

  /// @~english The standard video profile. 640 x 360 or 640 x 480, frame rate: 30 fps.
  /// @~chinese 标准档视频设定。分辨率：640 x 360 或 640 x 480，帧率：30 帧/秒。
  @JsonValue(2)
  Standard,

  /// @~english The 720P video profile. 1280 x 720, frame rate: 30 fps.
  /// @~chinese 高清档视频设定。分辨率：1280 x 720，帧率：30 帧/秒。
  @JsonValue(3)
  HD720P,

  /// @~english The 1080P video profile. 1920 x 1080, frame rate: 30 fps.
  /// @~chinese 全高清档视频设定。分辨率：1920 x 1080，帧率：30 帧/秒。
  @JsonValue(4)
  HD1080P,

  /// @~english None video profile. @~chinese 无视频设定。
  @JsonValue(5)
  None,

  /// @~english The max video profile. @~chinese 最高档视频设定。
  @JsonValue(4)
  Max,
}

/// @brief @~english Video scaling mode. @~chinese 视频缩放模式。
enum VideoScalingMode {
  /// @~english Fit the view, maintaining aspect ratio.
  /// @~chinese 适合视图，保持宽高比。
  @JsonValue(0)
  Fit,

  /// @~english Fully fill the view, without maintaining aspect ratio.
  /// @~chinese 全填充视图，不保持宽高比。
  @JsonValue(1)
  FullFill,

  /// @~english Crop and fill the view, maintaining aspect ratio.
  /// @~chinese 裁剪并填充视图，保持宽高比。
  @JsonValue(2)
  CropFill,
}

/// @brief @~english Audio type. @~chinese 音频类型。
enum AudioType {
  /// @~english The standard form of digital audio. @~chinese 数字音频的标准形式。
  @JsonValue(0)
  PCM,
}

/// @brief @~english Video type. @~chinese 视频类型。
enum VideoType {
  /// @~english The YUV standard format 4:2:0. @~chinese YUV标准格式4:2:0。
  @JsonValue(0)
  I420,
}

/// @brief @~english Video rotation value. @~chinese 视频旋转值。
enum VideoRotation {
  /// @~english The video is rorated 0 degrees. @~chinese 视频旋转0度。
  @JsonValue(0)
  Rotation0,

  /// @~english The video is rorated 90 degrees. @~chinese 视频旋转90度。
  @JsonValue(90)
  Rotation90,

  /// @~english The video is rorated 180 degrees. @~chinese 视频旋转180度。
  @JsonValue(180)
  Rotation180,

  /// @~english The video is rorated 270 degrees. @~chinese 视频旋转270度。
  @JsonValue(270)
  Rotation270,
}

/// @brief @~english Audio Device type. @~chinese 音频设备类型。
enum AudioDeviceType {
  /// @~english The unknown device. @~chinese 未知设备。
  @JsonValue(0)
  Unknown,

  /// @~english The audio record device. @~chinese 录音设备。
  @JsonValue(1)
  Record,

  /// @~english The audio playout device. @~chinese 音频播放设备。
  @JsonValue(2)
  Playout
}

/// @brief @~english Audio Device state. @~chinese 音频设备状态。
enum AudioDeviceState {
  /// @~english The device is actived. @~chinese 设备激活。
  @JsonValue(0)
  Active,

  /// @~english The device is inactived. @~chinese 设备未激活。
  @JsonValue(1)
  Inactive,
}

/// @brief @~english Video device type. @~chinese 视频设备类型。 */
enum VideoDeviceType {
  /// @~english The unknown device. @~chinese 未知设备。
  @JsonValue(0)
  Unknown,

  /// @~english The video capture device. @~chinese 视频抓取设备。
  @JsonValue(1)
  Capture
}

/// @brief @~english Video device state. @~chinese 视频设备状态。
enum VideoDeviceState {
  /// @~english The device is added. @~chinese 设备添加。
  @JsonValue(0)
  Added,

  /// @~english The device is removed. @~chinese 设备移除。
  @JsonValue(1)
  Removed,
}

/// @brief @~english Video capture state. @~chinese 视频采集状态。
enum VideoCaptureState {
  /// @~english Unknown video capture state. @~chinese 未知视频采集状态。
  @JsonValue(0)
  Unknown,

  /// @~english Video capture is normal. @~chinese 视频采集正常。
  @JsonValue(1)
  Normal,

  /// @~english Video capture is suspended. @~chinese 视频采集暂停。
  @JsonValue(2)
  Suspended,
}

/// @brief @~english Screen source type. @~chinese 屏幕源类型。
enum ScreenSourceType {
  /// @~english The source type is screen. @~chinese 屏幕型。
  @JsonValue(0)
  Screen,

  /// @~english The source type is application. @~chinese 应用型。
  @JsonValue(1)
  Applicaition,

  /// @~english The source type is window. @~chinese 窗口型。
  @JsonValue(2)
  Window,
}

/// @brief @~english Screen scaling ratio type. @~chinese 屏幕缩放比例类型。
enum ScreenScalingRatio {
  /// @~english The image ratio fitted for view. @~chinese 适合视图的图像比例。
  @JsonValue(0)
  FitRatio,

  /// @~english The image original ratio. @~chinese 图像原始比例。
  @JsonValue(1)
  OriginalRatio,
}

/// @brief @~english Whiteboard role type. @~chinese 白板角色类型。
enum WBRoleType {
  /// @~english The admin role. @~chinese 白板管理员。
  @JsonValue(0)
  Admin,

  /// @~english The normal attendee. @~chinese 普通白板参与者。
  @JsonValue(1)
  Attendee,

  /// @~english The view only attendee. @~chinese 只看白板参与者。
  @JsonValue(2)
  Viewer,
}

/// @brief @~english Whiteboard tool type. @~chinese 白板工具类型。
enum WBToolType {
  /// @~english None tool. @~chinese 空。
  @JsonValue(0)
  None,

  /// @~english Select tool. @~chinese 选择工具。
  @JsonValue(1)
  Select,

  /// @~english Path tool. @~chinese 路径工具。
  @JsonValue(2)
  Path,

  /// @~english Line tool. @~chinese 线条工具。
  @JsonValue(3)
  Line,

  /// @~english Rectangle tool. @~chinese 矩形工具。
  @JsonValue(4)
  Rect,

  /// @~english Ellipse tool. @~chinese 椭圆工具。
  @JsonValue(5)
  Ellipse,

  /// @~english Image tool. @~chinese 图像工具。
  @JsonValue(6)
  Image,

  /// @~english Text tool. @~chinese 文本工具。
  @JsonValue(7)
  Text,

  /// @~english Eraser tool. @~chinese 橡皮擦工具。
  @JsonValue(8)
  Eraser,

  /// @~english Brush tool. @~chinese 刷子工具。
  @JsonValue(9)
  Brush,

  /// @~english Arrow tool. @~chinese 箭头工具。
  @JsonValue(10)
  Arrow,

  /// @~english Polyline tool. Windows&MacOS only. @~chinese 折线工具。仅支持Windows及macOS平台。
  @JsonValue(11)
  Polyline,

  /// @~english Polygon tool. Windows&MacOS only. @~chinese 多边形工具。仅支持Windows及macOS平台。
  @JsonValue(12)
  Polygon,

  /// @~english Arc tool. Windows&MacOS only. @~chinese 弧线工具。仅支持Windows及macOS平台。
  @JsonValue(13)
  Arc,

  /// @~english Curve tool. Windows&MacOS only. @~chinese 曲线工具。仅支持Windows及macOS平台。
  @JsonValue(14)
  Curve,
}

/// @brief @~english Whiteboard fill type. @~chinese 白板填充类型。
enum WBFillType {
  /// @~english Fill none. @~chinese 不填充。
  @JsonValue(0)
  None,

  /// @~english Fill color. @~chinese 填色。
  @JsonValue(1)
  Color,
}

/// @brief @~english Whiteboard font style. @~chinese 白板字体样式。
enum WBFontStyle {
  /// @~english Normal font. @~chinese 正常字体。
  @JsonValue(0)
  Normal,

  /// @~english Bold font. @~chinese 粗体。
  @JsonValue(1)
  Bold,

  /// @~english Italic font. @~chinese 斜体。
  @JsonValue(2)
  Italic,

  /// @~english Bold italic font. @~chinese 粗斜体。
  @JsonValue(3)
  BoldItalic,
}

/// @brief @~english Whiteboard image scaling mode. @~chinese 白板图片缩放模式。
enum WBImageScalingMode {
  /// @~english Fit the view, maintaining aspect ratio.
  /// @~chinese 适合视图，保持宽高比。
  @JsonValue(0)
  Fit,

  /// @~english Fill the view automatically, maintaining aspect ratio, align top and left.
  /// @~chinese 自动填充视图，保持宽高比，左上对齐。
  @JsonValue(1)
  AutoFill,

  /// @~english Fill the view width, maintaining aspect ratio, align top.
  /// @~chinese 按宽填充视图，保持宽高比，顶侧对齐。
  @JsonValue(2)
  FillWidth,

  /// @~english Fill the view height, maintaining aspect ratio, align left.
  /// @~chinese 按高填充视图，保持宽高比，左侧对齐。
  @JsonValue(3)
  FillHeight,
}

/// @brief @~english Whiteboard image state. @~chinese 白板图片状态码。
enum WBImageState {
  /// @~english Start to load the image. @~chinese 开始加载图片。
  @JsonValue(0)
  LoadStart,

  /// @~english The image load complete. @~chinese 图片加载成功。
  @JsonValue(1)
  LoadComplete,

  /// @~english The image load failed. @~chinese 图片加载失败。
  @JsonValue(2)
  LoadFail,
}

/// @brief @~english Whiteboard clear type. @~chinese 白板清除类型。
enum WBClearType {
  /// @~english clear whiteboard draws objects. @~chinese 清除白板绘制对象
  @JsonValue(1)
  Draws,

  /// @~english clear whiteboard background image. @~chinese 清除白板背景图。
  @JsonValue(2)
  BackgroundImage,

  /// @~english clear whiteboard all content. @~chinese 清除全部白板内容。
  @JsonValue(255)
  All,
}

/// @brief @~english Whiteboard snapshot mode. @~chinese 白板快照模式。
enum WBSnapshotMode {
  /// @~english snapshot whiteboard view area. @~chinese 截取白板视图区域
  @JsonValue(0)
  View,

  /// @~english snapshot area with all objects. Not implement.
  /// @~chinese 截取所有白板对象。未实现
  @JsonValue(1)
  All,
}

/// @brief @~english Whiteboard option type. @~chinese 白板可选项类型。
enum WBOptionType {
  /// @~english Whiteboard file cache path, object type is NSString.
  /// @~chinese 白板文件缓存路径，对象类型是 NSString 。
  @JsonValue(1)
  FileCachePath,

  /// @~english Enable whiteboard response UI event flag, object type is NSNumber with BOOL value. Default is YES
  /// @~chinese 启用白板响应UI事件，对象类型是带BOOL值的NSNumber。默认启用
  @JsonValue(2)
  EnableUIResponse,
}

/// @brief @~english Option type. @~chinese 可选项类型。
enum OptionType {
  /// @~english Face beacutify option, object type is PanoFaceBeautifyOption.
  /// @~chinese 美颜可选项，对象类型是 PanoFaceBeautifyOption 。
  @JsonValue(0)
  FaceBeautify,

  /// @~english Logs upload option, object type is NSNumber with BOOL value.
  /// @~chinese 日志上传可选项，对象类型是带 BOOL 值的 NSNumber 。
  @JsonValue(1)
  UploadLogs,

  /// @~english Audio dump file upload option, object type is NSNumber with BOOL value.
  /// @~chinese 音频转储文件上传选项，对象类型是带 BOOL 值的 NSNumber 。
  @JsonValue(2)
  UploadAudioDump,

  /// @~english Audio equalization option, object type is NSNumber with PanoAudioEqualizationMode value.
  /// @~chinese 音频均衡器选项，对象类型是带 PanoAudioEqualizationMode 值的 NSNumber 。
  @JsonValue(3)
  AudioEqualizationMode,

  /// @~english Audio reverb option, object type is NSNumber with PanoAudioReverbMode value.
  /// @~chinese 音频混响器选项，对象类型是带 PanoAudioReverbMode 值的 NSNumber 。
  @JsonValue(4)
  AudioReverbMode,

  /// @~english Adjust video capture frame rate option, object type is NSNumber with PanoVideoFrameRateType value.
  /// @~chinese 调整视频采集帧率选项，对象类型是带 PanoVideoFrameRateType 值的 NSNumber 。
  @JsonValue(5)
  VideoFrameRate,

  /// @~english Audio ear Monitoring enable option, object type is NSNumber with BOOL value.
  /// @~chinese 音频耳返开关选项，对象类型是带 BOOL 值的 NSNumber 。
  @JsonValue(6)
  AudioEarMonitoring,

  /// @~english (Deprecated) Internal video transform option, object type is PanoBuiltinTransformOption.
  /// @~chinese (已废弃)视频内嵌变换可选项，对象类型是 PanoBuiltinTransformOption 。
  @deprecated
  @JsonValue(7)
  BuiltinTransform,

  /// @~english Enable upload PANO SDK logs when failed to join channel, object type is NSNumber with BOOL value.
  /// @note This flag has been set by default.
  /// @~chinese 允许加会失败时上传PANO日志，对象类型是带 BOOL 值的 NSNumber 。
  /// @note 此标记设置后会一直有效。默认已经启用。
  @JsonValue(8)
  UploadLogsAtFailure,

  /// @~english Allow SDK to adjust video quality according to CPU performance.
  ///           Object type is NSNumber with BOOL value. Default value is ture. Configurable before join room.
  /// @note We do not recommend disabling CPU adaption in general case.
  /// @~chinese 允许SDK根据CPU性能调整视频质量。对象类型是带 BOOL 值的 NSNumber 。默认值是true。仅在加入房间前可以配置。
  /// @note 通常场景下不建议关闭此功能。
  @JsonValue(9)
  CpuAdaption,

  /// @~english Audio profile option, object type is PanoRtcAudioProfile.
  /// @~chinese 音频配置选项，对象类型是 PanoRtcAudioProfile 。
  @JsonValue(10)
  AudioProfile,

  /// @~english Quadrilateral video transform option, object type is PanoQuadTransformOption.
  /// @~chinese 视频四边形变换可选项，对象类型是 PanoQuadTransformOption 。
  @JsonValue(11)
  QuadTransform,
}

/// @brief @~english Log output level. @~chinese 日志输出级别。
enum LogLevel {
  /// @~english Outputs FATAL level log information.
  /// @~chinese 输出FATAL级别日志信息。
  @JsonValue(0)
  Fatal,

  /// @~english Outputs FATAL and ERROR level log information.
  /// @~chinese 输出FATAL和ERROR级别日志信息。
  @JsonValue(1)
  Error,

  /// @~english Outputs FATAL, ERROR and WARNING level log information.
  /// @~chinese 输出FATAL、ERROR和WARNING级别日志信息。
  @JsonValue(2)
  Warning,

  /// @~english Outputs FATAL, ERROR, WARNING and INFO level log information.
  /// @~chinese 输出FATAL、ERROR、WARNING和INFO级别日志信息。
  @JsonValue(3)
  Info,

  /// @~english Outputs FATAL, ERROR, WARNING, INFO and VERBOSE level log information.
  /// @~chinese 输出FATAL、ERROR、WARNING、INFO和VERBOSE级别日志信息。
  @JsonValue(4)
  Verbose,

  /// @~english Outputs all level log information.
  /// @~chinese 输出所有级别日志信息。
  @JsonValue(5)
  Debug,
}

/// @brief @~english Feedback type. @~chinese 用户反馈问题类型。
enum FeedbackType {
  /// @~english General problem. @~chinese 通用类型。
  @JsonValue(0)
  General,

  /// @~english Audio problem. @~chinese 语音问题。
  @JsonValue(1)
  Audio,

  /// @~english Video problem. @~chinese 视频问题。
  @JsonValue(2)
  Video,

  /// @~english Whiteboard problem. @~chinese 白板问题。
  @JsonValue(3)
  Whiteboard,

  /// @~english Screen sharing problem. @~chinese 桌面共享问题。
  @JsonValue(4)
  Screen,
}

/// @brief @~english Audio mixing state. @~chinese 混音状态。
enum AudioMixingState {
  /// @~english Mixing started.  @~chinese 混音开始。
  @JsonValue(0)
  Started,

  /// @~english Mixing finished. @~chinese 混音结束。
  @JsonValue(1)
  Finished,
}

/// @brief @~english Image file format. @~chinese 图片文件格式。
enum ImageFileFormat {
  /// @~english JPEG. Lossy compression format. @~chinese JPEG。有损压缩格式。
  @JsonValue(0)
  JPEG,

  /// @~english PNG. Lossless compression format. @~chinese PNG。无损压缩格式。
  @JsonValue(1)
  PNG,

  /// @~english BMP. Uncompressed format.  @~chinese BMP。无压缩格式。
  @JsonValue(2)
  BMP,
}

/// @brief @~english Audio equalization option @~chinese 音频均衡器选项。
enum AudioEqualizationMode {
  /// @~english None.  @~chinese  无音效
  @JsonValue(0)
  None,

  /// @~english Bass.  @~chinese  低音
  @JsonValue(1)
  Bass,

  /// @~english Loud.  @~chinese  高音
  @JsonValue(2)
  Loud,

  /// @~english Vocal Music.  @~chinese  声乐
  @JsonValue(3)
  VocalMusic,

  /// @~english Strong.  @~chinese  增强
  @JsonValue(4)
  Strong,

  /// @~english Pop.  @~chinese  流行
  @JsonValue(5)
  Pop,

  /// @~english Live.  @~chinese 现场
  @JsonValue(6)
  Live,

  /// @~english Dance Music.  @~chinese  舞曲
  @JsonValue(7)
  DanceMusic,

  /// @~english Club.  @~chinese  俱乐部
  @JsonValue(8)
  Club,

  /// @~english Soft.  @~chinese 轻柔
  @JsonValue(9)
  Soft,

  /// @~english Rock.  @~chinese  摇滚
  @JsonValue(10)
  Rock,

  /// @~english Party.  @~chinese  聚会
  @JsonValue(11)
  Party,

  /// @~english Classical.  @~chinese 古典
  @JsonValue(12)
  Classical,

  /// @~english Test.  @~chinese 测试用例
  @JsonValue(13)
  Test,
}

enum AudioReverbMode {
  /// @~english None.  @~chinese 无音效
  @JsonValue(0)
  None,

  /// @~english Vocal I.  @~chinese 人声 1
  @JsonValue(1)
  VocalI,

  /// @~english Vocal II.  @~chinese 人声 2
  @JsonValue(2)
  VocalII,

  /// @~english Bathroom.  @~chinese 浴室
  @JsonValue(3)
  Bathroom,

  /// @~english Small room bright.  @~chinese 明亮小房间
  @JsonValue(4)
  SmallRoomBright,

  /// @~english Small room dark.  @~chinese 黑暗小房间
  @JsonValue(5)
  SmallRoomDark,

  /// @~english Medium room.  @~chinese 中等房间
  @JsonValue(6)
  MediumRoom,

  /// @~english Large room.  @~chinese 大房间
  @JsonValue(7)
  LargeRoom,

  /// @~english Church hall.  @~chinese 教堂大厅
  @JsonValue(8)
  ChurchHall,

  /// @~english Cathedral.  @~chinese 大教堂
  @JsonValue(9)
  Cathedral,
}

/// @brief @~english Video frame rate type. @~chinese 视频帧率类型。
enum VideoFrameRateType {
  /// @~english The max frame rate is 15 fps. @~chinese 最大帧率 15 fps。
  @JsonValue(0)
  Low,

  /// @~english The max frame rate is 30 fps. @~chinese 最大帧率 30 fps。
  @JsonValue(1)
  Standard,
}

/// @brief  @~english Video Codec Type. @~chinese 视频编解码器类型。
enum VideoCodecType {
  /// @~english unknown Codec. @~chinese 未知编解码器.
  @JsonValue(0)
  Unknown,

  /// @~english H.264 Codec. @~chinese H.264编解码.
  @JsonValue(1)
  H264,

  /// @~english AV1 Codec. @~chinese AV1编解码.
  @JsonValue(2)
  AV1,
}

/// @brief  @~english Audio Codec Type. @~chinese 音频编解码器类型。
enum AudioCodecType {
  /// @~english unknown Codec. @~chinese 未知编解码器.
  @JsonValue(0)
  Unknown,

  /// @~english G.711 Codec. @~chinese G.711编解码器.
  @JsonValue(1)
  G711,

  /// @~english G.722 Codec. @~chinese G.722编解码器.
  @JsonValue(2)
  G722,

  /// @~english iLBC Codec. @~chinese iLBC编解码器.
  @JsonValue(3)
  ILBC,

  /// @~english iSAC Codec. @~chinese iSAC编解码器.
  @JsonValue(4)
  ISAC,

  /// @~english Opus Codec. @~chinese Opus编解码器.
  @JsonValue(5)
  OPUS,
}

/// @brief  @~english Audio Sample Rate. @~chinese 音频采样率。
enum AudioSampleRate {
  /// @~english Audio sample rate16000Hz. @~chinese 音频采样率16000Hz.
  @JsonValue(16000)
  Rate16K,

  /// @~english Audio sample rate48000Hz. @~chinese 音频采样率48000Hz.
  @JsonValue(48000)
  Rate48K,
}

/// @brief  @~english Audio Channel. @~chinese 音频采样率。
enum AudioChannel {
  /// @~english Audio channel mono. @~chinese 音频单通道.
  @JsonValue(1)
  Mono,

  /// @~english Audio channel stereo. @~chinese 音频双通道.
  @JsonValue(2)
  Stereo,
}

/// @brief  @~english Audio Profile Quality. @~chinese 音频质量配置。
enum AudioProfileQuality {
  /// @~english Audio quality default: encode bitrate - 48kbps. @~chinese 音频默认质量: 编码最大码率 48kbps
  @JsonValue(0)
  Default,

  /// @~english Audio high quality: encode bitrate - 128kbps. @~chinese 音频质量: 编码最大码率 128kbps
  @JsonValue(1)
  High,
}

/// @brief @~english Quality rating values. @~chinese 质量评分分值。
enum QualityRating {
  /// @~english Service not available. @~chinese 服务不可用。
  @JsonValue(0)
  Unavailable,

  /// @~english The quality is very bad. @~chinese 服务质量非常差，几乎不可用。
  @JsonValue(1)
  VeryBad,

  /// @~english The quality is bad. @~chinese 服务质量比较差，质量不稳定。
  @JsonValue(2)
  Bad,

  /// @~english The quality is poor. @~chinese 服务质量一般。
  @JsonValue(3)
  Poor,

  /// @~english The quality is good. @~chinese 服务质量很好。
  @JsonValue(4)
  Good,

  /// @~english The quality is excellent. @~chinese 服务质量非常好。
  @JsonValue(5)
  Excellent,
}

/// @brief @~english Media processor type. @~chinese 媒体处理类型。
enum MediaProcessorType {
  /// @~english Audio Capture External Processor for data before local process.
  ///           The processor must be PanoRtcAudioDataExProcessorDelegate pointer or nullptr.
  ///           And the param shoubld be nullptr.
  /// @~chinese 音频采集外部处理(位置位于本地采集后，前处理前)。
  ///           对应的处理模块必须为 PanoRtcAudioDataExProcessorDelegate 指针类型或空，对应的处理模块参数必须为空。
  @JsonValue(1)
  AudioCaptureExProcessor,

  /// @~english Audio Capture External Effect Processor for data after local process and before encoder.
  ///           The processor must be PanoRtcAudioDataExProcessorDelegate pointer or nullptr.
  ///           And the param shoubld be nullptr.
  /// @~chinese 音频采集外部处理(位置位于本地处理后，编码前)。
  ///           对应的处理模块必须为 PanoRtcAudioDataExProcessorDelegate 指针类型或空，对应的处理模块参数必须为空。
  @JsonValue(2)
  AudioCaptureExEffectProcessor,

  /// @~english Audio Capture External Processor for before playback.
  ///           The processor must be PanoRtcAudioDataExProcessorDelegate pointer or nullptr.
  ///           And the param shoubld be nullptr.
  /// @~chinese 音频采集外部处理(位置位于播放前)。
  ///           对应的处理模块必须为 PanoRtcAudioDataExProcessorDelegate 指针类型或空，对应的处理模块参数必须为空。
  @JsonValue(3)
  AudioRenderExProcessor,

  /// @~english Video Preprocessor. The processor must be PanoRtcVideoFilterDelegate or nil.
  ///           And the param should be nil.
  /// @~chinese 视频前处理。对应的处理模块必须为 PanoRtcVideoFilterDelegate 代理或空，对应的处理模块参数必须为空。
  @JsonValue(100)
  VideoPreprocessor,
}

/// @brief @~english Quadrilateral vertex index. @~chinese 四边形顶点索引。
enum QuadIndex {
  /// @~english The top left of a quadrilateral.
  /// @~chinese 四边形左上角顶点。
  @JsonValue(0)
  TopLeft,

  /// @~english The top right of a quadrilateral.
  /// @~chinese 四边形右上角顶点。
  @JsonValue(1)
  TopRight,

  /// @~english The top right of a quadrilateral.
  /// @~chinese 四边形右上角顶点。
  @JsonValue(2)
  BottomLeft,

  /// @~english The top right of a quadrilateral.
  /// @~chinese 四边形右上角顶点。
  @JsonValue(3)
  BottomRight,
}
